#!/usr/bin/python
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#   bumptext-2.0 MrQ: update for Gimp-2.10

import re
import math
from gimpfu import *

def python_bumptext_watermark(image, drawable, text, font, text_size, blur, depth, x, y, rotation, invert):
    
	
    pdb.gimp_image_undo_group_start(image)
    pdb.gimp_context_push()
	
    pdb.gimp_edit_copy(drawable)
    copy = pdb.gimp_edit_paste(drawable ,1)
    pdb.gimp_floating_sel_to_layer(copy)
    pdb.gimp_image_lower_item_to_bottom(image, copy)
	
	
    #save the back and foreground colors
    background = gimp.get_background()
    foreground = gimp.get_foreground()
	
    #set the back and foreground colors
    gimp.set_background(255, 255, 255)
    gimp.set_foreground(0, 0, 0)
	
    base_type = pdb.gimp_image_base_type(image)
    if base_type>0:
        pdb.gimp_image_convert_rgb(image)
		
    #create the text layer and fill it
    textlayer = gimp.Layer(image, "textlayer", drawable.width, drawable.height, RGBA_IMAGE, 100, LAYER_MODE_NORMAL_LEGACY )
    image.add_layer(textlayer, 0)
    pdb.gimp_drawable_fill(textlayer, 0)
    #create the text
    gimp.set_background(0, 0, 0)
    gimp.set_foreground(255, 255, 255)
	#pdb.gimp_text_fontname(image, drawable, x, y, text, border, antialias, size, size_type, fontname)
    floattext = pdb.gimp_text_fontname(image, textlayer, x, y, text, 1, 1, text_size, 1, font)
	
    #rotate the text
    if rotation != 0:
        #set the floating selection rotation center
        centerx = floattext.width /2 + x
        centery = floattext.height /2 + y
        rotation = math.radians(rotation)
        pdb.gimp_drawable_transform_rotate_default(floattext, rotation, 0, centerx, centery, 1, 0)
    #anchor the floating text
    pdb.gimp_floating_sel_anchor(floattext)
    #blur the text
    pdb.plug_in_gauss(image, textlayer, blur, blur, 0)
    #bump the image
    pdb.plug_in_bump_map(image, drawable, textlayer, 135, 45, depth, 0, 0, 0, 0, 1, invert, 0)
    #delete the textlayer and clean up
    image.remove_layer(textlayer)
    
    #reset to original back and foreground
    gimp.set_background(background)
    gimp.set_foreground(foreground)
	
    pdb.gimp_context_pop()
    pdb.gimp_image_undo_group_end(image) 
	
register(
    "python_fu_bumptext_watermark",
    "Bump image with specified text",
    "Bumps the input text on the selected layer. Great for watermarking.",
    "Jason T. Powell",
    "GPL",
    "2005/2022",
    "Bump Text...",
    "*",
    [
    (PF_IMAGE,   "image", "Input image", None),
    (PF_DRAWABLE,"drawable", "Input layer", None),
    (PF_TEXT,    "text", "Text to bump", u"\xa9 gimpscripts.net"),
    (PF_FONT,    "font", "Choose Font", "Sans-serif"),
    (PF_SPINNER, "text_size", "Text size", 50, [10, 5000, 1]),	
    (PF_SPINNER, "blur", "Text blur", 5, [0, 500, 1]),
    (PF_SPINNER, "depth", "Depth", 15, [1, 65, 1]),
    (PF_SPINNER, "x", "Text X Placement", 0, [0, 5000, 1]),
    (PF_SPINNER, "y", "Text Y Placement",0, [0, 5000, 1]),
    (PF_SPINNER, "rotation", "Text Rotation", 0, [-180, 180, 1]),
    (PF_TOGGLE,  "invert", "Invert Bump", 0)
    ],
    [],
    python_bumptext_watermark,
    menu="<Image>/Filters/Watermark/")
main()

#GPL Last modified 02-12-10

